part
====

.. automodule:: abjad.demos.part

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.demos.part.PartCantusScoreTemplate.PartCantusScoreTemplate

   Functions
   ---------

   .. autosummary::

      ~abjad.demos.part.add_bell_music_to_score.add_bell_music_to_score
      ~abjad.demos.part.add_string_music_to_score.add_string_music_to_score
      ~abjad.demos.part.apply_bowing_marks.apply_bowing_marks
      ~abjad.demos.part.apply_dynamics.apply_dynamics
      ~abjad.demos.part.apply_expressive_marks.apply_expressive_marks
      ~abjad.demos.part.apply_final_bar_lines.apply_final_bar_lines
      ~abjad.demos.part.apply_page_breaks.apply_page_breaks
      ~abjad.demos.part.apply_rehearsal_marks.apply_rehearsal_marks
      ~abjad.demos.part.configure_lilypond_file.configure_lilypond_file
      ~abjad.demos.part.configure_score.configure_score
      ~abjad.demos.part.create_pitch_contour_reservoir.create_pitch_contour_reservoir
      ~abjad.demos.part.durate_pitch_contour_reservoir.durate_pitch_contour_reservoir
      ~abjad.demos.part.edit_bass_voice.edit_bass_voice
      ~abjad.demos.part.edit_cello_voice.edit_cello_voice
      ~abjad.demos.part.edit_first_violin_voice.edit_first_violin_voice
      ~abjad.demos.part.edit_second_violin_voice.edit_second_violin_voice
      ~abjad.demos.part.edit_viola_voice.edit_viola_voice
      ~abjad.demos.part.make_part_lilypond_file.make_part_lilypond_file
      ~abjad.demos.part.shadow_pitch_contour_reservoir.shadow_pitch_contour_reservoir
